Welcome to aioqbt's documentation!
==================================

**aioqbt** is a Python library for qBittorrent WebAPI.
It is built on
`asyncio <https://docs.python.org/3/library/asyncio.html>`_ and
`aiohttp <https://docs.aiohttp.org/en/stable/index.html>`_.

The library features asynchronous typed interfaces and tests on qBittorrent up to v4.6.1.

Check out :doc:`usage` section for further information, including how to
:ref:`install <installation>` the project.

The source code is hosted at `GitHub <https://github.com/tsangwpx/aioqbt>`_
and released under MIT License.

.. toctree::
    :maxdepth: 2
    :caption: Documentation

    usage
    advanced
    reference
    status

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
